@@ -4,8 +4,8 @@ use autodie;
 use Term::ANSIColor;
 use Data::Dumper;
 use Carp qw(confess);
-use FindBin qw($Bin);
-use lib "$Bin/../lib/";
+use FindBin qw($RealBin);
+use lib "$RealBin/../lib/";
 use FASTX::Reader;
 my $seq_reader;
 $seq_reader = FASTX::Reader->new();
